# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.30) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to patch the test suite if we have old versions of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# Test::Requires needs Test::Builder::Module, only available if we have perl ≥ 5.8.8 (FC-5 onwards)
%global no_test_requires %(perl -e 'print $] >= 5.008008 ? 0 : 1;' 2>/dev/null || echo 0)

#TODO: BR: Test::Pod::No404s when available
#TODO: BR: Test::Pod::LinkCheck when available

Name:		perl-Class-Load
Version:	0.18
Release:	1.%{__distinit}%{__distvers}
Summary:	A working (require "Class::Name") and more
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Class-Load/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DR/DROLSKY/Class-Load-%{version}.tar.gz
Patch0:		Class-Load-0.15-old-Test::More.patch
Patch2:		Class-Load-0.09-old-eu::mm.patch
Patch3:		Class-Load-0.14-no-Test::Requires.patch
Patch5:		Class-Load-0.08-stopwords.patch
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# ===================================================================
# Module build requirements
# ===================================================================
BuildRequires:	perl(ExtUtils::MakeMaker)
# ===================================================================
# Module requirements
# ===================================================================
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Data::OptList)
BuildRequires:	perl(Module::Implementation) >= 0.04
BuildRequires:	perl(Module::Runtime) >= 0.012
BuildRequires:	perl(Package::Stash) >= 0.14
BuildRequires:	perl(strict)
BuildRequires:	perl(Try::Tiny)
BuildRequires:	perl(warnings)
# ===================================================================
# Regular test suite requirements
# ===================================================================
# Class::Load::XS -> Class::Load
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Class::Load::XS)
%endif
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More)
# Test::Without::Module incompatible with Package::Stash::XS in perl ≤ 5.8.6 (CPAN RT#74151)
%if %(perl -e 'print $] > 5.008006 ? 1 : 0;')
BuildRequires:	perl(Test::Without::Module)
%endif
BuildRequires:	perl(version)
# ===================================================================
# Author/Release test requirements
# ===================================================================
# Pod::Coverage::Moose -> Moose -> Class::Load
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Pod::Coverage::Moose)
%endif
# Test::CPAN::Changes only available if we have Perl 5.10.0 onwards
%if %(perl -e 'print $] >= 5.010000 ? 1 : 0;')
BuildRequires:	perl(Test::CPAN::Changes)
%endif
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
# Test::Requires needs Test::Builder::Module, only available if we have perl ≥ 5.8.8 (FC-5 onwards)
%if ! %{no_test_requires}
BuildRequires:	perl(Test::Requires)
%endif
BuildRequires:	perl(Test::Spelling), aspell-en
# ===================================================================
# Runtime requirements
# ===================================================================
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
require EXPR only accepts Class/Name.pm style module names, not Class::Name.
How frustrating! For that, we provide load_class 'Class::Name'.

It's often useful to test whether a module can be loaded, instead of throwing
an error when it's not available. For that, we provide
try_load_class 'Class::Name'.

Finally, sometimes we need to know whether a particular class has been loaded.
Asking %%INC is an option, but that will miss inner packages and any class for
which the filename does not correspond to the package name. For that, we
provide is_class_loaded 'Class::Name'.

%prep
%setup -q -n Class-Load-%{version}

# We need to patch the test suite if we have old versions of Test::More
%if %{old_test_more}
%patch0 -p1
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%if %{old_eumm}
%patch2 -p1
%endif

# Test::Requires needs Test::Builder::Module, only available if we have perl ≥ 5.8.8 (FC-5 onwards)
%if %{no_test_requires}
%patch3 -p1
%endif

# Add extra stopwords to spell check test to account for dictionary
# coverage differences between distros
%patch5 -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
%{_fixperms} %{buildroot}

%check
make test %{!?perl_bootstrap:RELEASE_TESTING=1}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE README
%{perl_vendorlib}/Class/
%{_mandir}/man3/Class::Load.3pm*

%changelog
* Sat Feb 18 2012 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18:
  - Require Package::Stash ≥ 0.14 (CPAN RT#75095)

* Sun Feb 12 2012 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17:
  - Require Module::Runtime 0.012, which has a number of useful bug fixes
  - A bug in Class::Load caused test failures when Module::Runtime 0.012 was
    used with Perl 5.8.x (CPAN RT#74897)

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15:
  - Small test changes to accomodate latest version of Module::Implementation
- BR: at least version 0.04 of perl(Module::Implementation)
- Update patch for old Test::More versions

* Wed Feb  8 2012 Paul Howarth <paul@city-fan.org> - 0.14-2
- Don't BR: perl(Class::Load::XS) or perl(Pod::Coverage::Moose) if we're
  bootstrapping
- Don't run the release tests when bootstrapping as the Pod coverage test will
  fail in the absence of Pod::Coverage::Moose

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14:
  - Use Module::Implementation to handle loading the XS or PP versions of the
    code; using this module fixes a few bugs
  - Under taint mode, setting an implementation in the
    CLASS_LOAD_IMPLEMENTATION env var caused a taint error
  - An invalid value in the CLASS_LOAD_IMPLEMENTATION env var is now detected
    and reported immediately; no attempt is made to load an invalid
    implementation
- BR: perl(Module::Implementation)
- BR: perl(base), perl(Carp), perl(strict) and perl(warnings) for completeness
- Drop version requirement for perl(Package::Stash), no longer present upstream
- Drop explicit runtime dependencies, no longer needed
- Update patches for old distros

* Thu Dec 22 2011 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13:
  - Fix some bugs with our use of Try::Tiny, which could cause warnings on some
    systems where Class::Load::XS wasn't installed (CPAN RT#72345)
- BR: perl(Test::Without::Module), but only if we have perl > 5.8.6 as the
  module appears to be incompatible with Package::Stash::XS on older perls
  (CPAN RT#74151)
- Update patches for old distros

* Tue Oct 25 2011 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12:
  - Require Module::Runtime ≥ 0.011, which fixes problems with Catalyst under
    Perl 5.8 and 5.10
- Add versioned runtime dependencies for Module::Runtime and Package::Stash

* Wed Oct  5 2011 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11:
  - Don't accept package names that start with a digit
  - Rewrite some of the guts to use Module::Runtime rather than reimplementing
    its functionality
- Drop patches to support building without Test::Fatal or Pod::Coverage::Moose
  since these are only needed with perl < 5.8.1 and we need at least 5.8.1 for
  Package::Stash
- Update patch for building with old Test::More versions

* Tue Sep  6 2011 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10:
  - Make sure the $@ localization doesn't hide errors - invalid module name
    errors were being suppressed on perls before 5.14

* Tue Sep  6 2011 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09:
  - Fix is_class_loaded to ignore $ISA (but still look for @ISA) when trying to
    determine whether a class is loaded
  - Lots of internals cleanup
- BR: perl(Package::Stash) ≥ 0.32 and perl(Try::Tiny)
- BR: aspell-en rather than just aspell with perl ≥ 5.8.1
- Update patches to apply cleanly

* Tue Aug 16 2011 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08:
  - The previous version was missing a prereq declaration for Data::OptList
    (CPAN RT#70285)
- This release by DROLSKY -> update source URL
- Package new documentation: LICENSE and README
- Add build requirements for new release tests and run them:
  - perl(Pod::Coverage::Moose)
  - perl(Test::CPAN::Changes)
  - perl(Test::EOL)
  - perl(Test::NoTabs)
  - perl(Test::Pod)
  - perl(Test::Pod::Coverage)
  - perl(Test::Requires)
  - perl(Test::Spelling) and aspell/aspell-en-gb
- Add patch for building with ExtUtils::MakeMaker < 6.30
- Add patch for building with Test::More < 0.88
- Add patch for building without Pod::Coverage::Moose
- Add patch for building without Test::Requires
- Add patch for fixing spell checker word list
- Update patch for building without Test::Fatal (using Test::Exception)

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 0.06-5
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Nov 22 2010 Paul Howarth <paul@city-fan.org> - 0.06-1
- Initial RPM version
